@@ -1,5 +1,5 @@
 package POD::Generate;
-use 5.006; use strict; use warnings; our $VERSION = q|0.01|;
+use 5.006; use strict; use warnings; our $VERSION = q|0.02|;
 
 use overload 
 	q|${}| => sub { $_[0]->generate(q|string|) },
@@ -303,10 +303,6 @@ sub _default_support_items {
 		q|* RT: CPAN's request tracker (report bugs here)|,
 		sprintf(q|L<https://rt.cpan.org/NoAuth/Bugs.html?Dist=%s>|, $formatted_name)
 	];
-	push @items, [
-		q|* CPAN Ratings|,
-		sprintf(q|L<https://cpanratings.perl.org/d/%s>|, $formatted_name)
-	];
 	push @items, [
 		q|* Search CPAN|,
 		sprintf(q|L<https://metacpan.org/release/%s>|, $formatted_name)
@@ -420,7 +416,7 @@ POD::Generate - programmatically generate plain old documentation
 
 =head1 VERSION
 
-v0.01
+v0.02
 
 =cut
 
@@ -547,10 +543,6 @@ produces...
 
 	L<https://rt.cpan.org/NoAuth/Bugs.html?Dist=Test-Memory
 
-	=item * CPAN Ratings
-
-	L<https://cpanratings.perl.org/d/Test-Memory>
-
 	=item * Search CPAN
 
 	L<https://metacpan.org/release/Test-Memory>
@@ -1017,10 +1009,6 @@ You can also look for information at:
 
 L<https://rt.cpan.org/NoAuth/Bugs.html?Dist=POD-Generate>
 
-=item * CPAN Ratings
-
-L<https://cpanratings.perl.org/d/POD-Generate>
-
 =item * Search CPAN
 
 L<https://metacpan.org/release/POD-Generate>
@@ -1041,4 +1029,4 @@ This is free software, licensed under:
 
 	The Artistic License 2.0 (GPL Compatible)
 
-=cut
\ No newline at end of file
+=cut
